@@ -47,7 +47,7 @@ class Document:
             stanza_sentences: [list],
             stanza_entities,
             entity_mapper: Optional[EntityMapper] = None,
-            doc_path: str = "text",
+            doc_path: str = "text_mlp",
             json_doc: dict = None,
             analyzers: list = [],
             error: str = "",
@@ -154,7 +154,6 @@ class Document:
                     new_end = new_start + span_len
                     new_span = [new_start, new_end]
                     new_spans.append(new_span)
-                print(new_spans)
             # update spans in object
             if new_spans:
                 fact.spans = new_spans
@@ -184,7 +183,7 @@ class Document:
         path_to_mlp = list_of_path_keys[:-1] + [root_key] if len(list_of_path_keys) > 1 else [root_key]
         mlp_result = self.to_json(use_default_doc_path)
         nested_dict_wrapper = PelicanJson(self.json_doc)
-        nested_dict_wrapper.set_nested_value(path_to_mlp, mlp_result["text"], force=True)
+        nested_dict_wrapper.set_nested_value(path_to_mlp, mlp_result["text_mlp"], force=True)
         nested_dict_wrapper.set_nested_value(["texta_facts"], mlp_result["texta_facts"], force=True)
 
         return nested_dict_wrapper.convert()
@@ -209,8 +208,8 @@ class Document:
             container["transliteration"] = self.get_transliteration()
         if use_default_doc_path:
             for fact in texta_facts["texta_facts"]:
-                fact["doc_path"] = "text.text"
-        return {"text": container, **texta_facts}
+                fact["doc_path"] = "text_mlp.text"
+        return {"text_mlp": container, **texta_facts}
 
 
     def lemmas(self):
